# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorProxyRequestStatsDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'started': 'int',
        'finished': 'int',
        'status_1xx': 'int',
        'status_2xx': 'int',
        'status_3xx': 'int',
        'status_4xx': 'int',
        'status_5xx': 'int',
        'status_unknown': 'int',
        'failed_authentication': 'int',
        'failed_authorisation': 'int'
    }

    attribute_map = {
        'started': 'started',
        'finished': 'finished',
        'status_1xx': 'status_1xx',
        'status_2xx': 'status_2xx',
        'status_3xx': 'status_3xx',
        'status_4xx': 'status_4xx',
        'status_5xx': 'status_5xx',
        'status_unknown': 'status_unknown',
        'failed_authentication': 'failed_authentication',
        'failed_authorisation': 'failed_authorisation'
    }

    def __init__(self, started=None, finished=None, status_1xx=None, status_2xx=None, status_3xx=None, status_4xx=None, status_5xx=None, status_unknown=None, failed_authentication=None, failed_authorisation=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorProxyRequestStatsDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._started = None
        self._finished = None
        self._status_1xx = None
        self._status_2xx = None
        self._status_3xx = None
        self._status_4xx = None
        self._status_5xx = None
        self._status_unknown = None
        self._failed_authentication = None
        self._failed_authorisation = None
        self.discriminator = None

        self.started = started
        self.finished = finished
        self.status_1xx = status_1xx
        self.status_2xx = status_2xx
        self.status_3xx = status_3xx
        self.status_4xx = status_4xx
        self.status_5xx = status_5xx
        self.status_unknown = status_unknown
        self.failed_authentication = failed_authentication
        self.failed_authorisation = failed_authorisation

    @property
    def started(self):
        """Gets the started of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The total number of requests started by the proxy  # noqa: E501

        :return: The started of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._started

    @started.setter
    def started(self, started):
        """Sets the started of this AgentConnectorProxyRequestStatsDetails.

        The total number of requests started by the proxy  # noqa: E501

        :param started: The started of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and started is None:  # noqa: E501
            raise ValueError("Invalid value for `started`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                started is not None and started < 0):  # noqa: E501
            raise ValueError("Invalid value for `started`, must be a value greater than or equal to `0`")  # noqa: E501

        self._started = started

    @property
    def finished(self):
        """Gets the finished of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The total number of requests finished by the proxy.  # noqa: E501

        :return: The finished of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this AgentConnectorProxyRequestStatsDetails.

        The total number of requests finished by the proxy.  # noqa: E501

        :param finished: The finished of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and finished is None:  # noqa: E501
            raise ValueError("Invalid value for `finished`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                finished is not None and finished < 0):  # noqa: E501
            raise ValueError("Invalid value for `finished`, must be a value greater than or equal to `0`")  # noqa: E501

        self._finished = finished

    @property
    def status_1xx(self):
        """Gets the status_1xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 100 and 199   # noqa: E501

        :return: The status_1xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_1xx

    @status_1xx.setter
    def status_1xx(self, status_1xx):
        """Sets the status_1xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 100 and 199   # noqa: E501

        :param status_1xx: The status_1xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_1xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_1xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_1xx is not None and status_1xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_1xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_1xx = status_1xx

    @property
    def status_2xx(self):
        """Gets the status_2xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 200 and 299   # noqa: E501

        :return: The status_2xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_2xx

    @status_2xx.setter
    def status_2xx(self, status_2xx):
        """Sets the status_2xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 200 and 299   # noqa: E501

        :param status_2xx: The status_2xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_2xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_2xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_2xx is not None and status_2xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_2xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_2xx = status_2xx

    @property
    def status_3xx(self):
        """Gets the status_3xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 300 and 399   # noqa: E501

        :return: The status_3xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_3xx

    @status_3xx.setter
    def status_3xx(self, status_3xx):
        """Sets the status_3xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 300 and 399   # noqa: E501

        :param status_3xx: The status_3xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_3xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_3xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_3xx is not None and status_3xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_3xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_3xx = status_3xx

    @property
    def status_4xx(self):
        """Gets the status_4xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 400 and 499   # noqa: E501

        :return: The status_4xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_4xx

    @status_4xx.setter
    def status_4xx(self, status_4xx):
        """Sets the status_4xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 400 and 499   # noqa: E501

        :param status_4xx: The status_4xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_4xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_4xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_4xx is not None and status_4xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_4xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_4xx = status_4xx

    @property
    def status_5xx(self):
        """Gets the status_5xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with a status code between 500 and 599   # noqa: E501

        :return: The status_5xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_5xx

    @status_5xx.setter
    def status_5xx(self, status_5xx):
        """Sets the status_5xx of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with a status code between 500 and 599   # noqa: E501

        :param status_5xx: The status_5xx of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_5xx is None:  # noqa: E501
            raise ValueError("Invalid value for `status_5xx`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_5xx is not None and status_5xx < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_5xx`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_5xx = status_5xx

    @property
    def status_unknown(self):
        """Gets the status_unknown of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which completed with an unknown status code   # noqa: E501

        :return: The status_unknown of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_unknown

    @status_unknown.setter
    def status_unknown(self, status_unknown):
        """Sets the status_unknown of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which completed with an unknown status code   # noqa: E501

        :param status_unknown: The status_unknown of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status_unknown is None:  # noqa: E501
            raise ValueError("Invalid value for `status_unknown`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_unknown is not None and status_unknown < 0):  # noqa: E501
            raise ValueError("Invalid value for `status_unknown`, must be a value greater than or equal to `0`")  # noqa: E501

        self._status_unknown = status_unknown

    @property
    def failed_authentication(self):
        """Gets the failed_authentication of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which failed authentication.   # noqa: E501

        :return: The failed_authentication of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._failed_authentication

    @failed_authentication.setter
    def failed_authentication(self, failed_authentication):
        """Sets the failed_authentication of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which failed authentication.   # noqa: E501

        :param failed_authentication: The failed_authentication of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_authentication is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_authentication`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                failed_authentication is not None and failed_authentication < 0):  # noqa: E501
            raise ValueError("Invalid value for `failed_authentication`, must be a value greater than or equal to `0`")  # noqa: E501

        self._failed_authentication = failed_authentication

    @property
    def failed_authorisation(self):
        """Gets the failed_authorisation of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501

        The number of requests which failed authorisation.   # noqa: E501

        :return: The failed_authorisation of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :rtype: int
        """
        return self._failed_authorisation

    @failed_authorisation.setter
    def failed_authorisation(self, failed_authorisation):
        """Sets the failed_authorisation of this AgentConnectorProxyRequestStatsDetails.

        The number of requests which failed authorisation.   # noqa: E501

        :param failed_authorisation: The failed_authorisation of this AgentConnectorProxyRequestStatsDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_authorisation is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_authorisation`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                failed_authorisation is not None and failed_authorisation < 0):  # noqa: E501
            raise ValueError("Invalid value for `failed_authorisation`, must be a value greater than or equal to `0`")  # noqa: E501

        self._failed_authorisation = failed_authorisation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorProxyRequestStatsDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorProxyRequestStatsDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class PolicyCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'condition_type': 'str',
        'inverted': 'bool',
        'input_is_list': 'bool',
        'value': 'str',
        'operator': 'str',
        'field': 'str',
        'created': 'datetime',
        'updated': 'datetime'
    }

    attribute_map = {
        'condition_type': 'condition_type',
        'inverted': 'inverted',
        'input_is_list': 'input_is_list',
        'value': 'value',
        'operator': 'operator',
        'field': 'field',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, condition_type=None, inverted=False, input_is_list=False, value=None, operator=None, field=None, created=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """PolicyCondition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._condition_type = None
        self._inverted = None
        self._input_is_list = None
        self._value = None
        self._operator = None
        self._field = None
        self._created = None
        self._updated = None
        self.discriminator = None

        self.condition_type = condition_type
        if inverted is not None:
            self.inverted = inverted
        if input_is_list is not None:
            self.input_is_list = input_is_list
        self.value = value
        self.operator = operator
        if field is not None:
            self.field = field
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def condition_type(self):
        """Gets the condition_type of this PolicyCondition.  # noqa: E501

        The type of this condition. The type determines how the value will be evaluated. This parameter is case sensitive.  # noqa: E501

        :return: The condition_type of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._condition_type

    @condition_type.setter
    def condition_type(self, condition_type):
        """Sets the condition_type of this PolicyCondition.

        The type of this condition. The type determines how the value will be evaluated. This parameter is case sensitive.  # noqa: E501

        :param condition_type: The condition_type of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and condition_type is None:  # noqa: E501
            raise ValueError("Invalid value for `condition_type`, must not be `None`")  # noqa: E501
        allowed_values = ["type_client_id_list", "type_org_id_list", "type_user_id_list", "type_upstream_idp_list", "type_ip_in_cidr_list", "type_last_successful_mfa", "type_object_attribute"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and condition_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `condition_type` ({0}), must be one of {1}"  # noqa: E501
                .format(condition_type, allowed_values)
            )

        self._condition_type = condition_type

    @property
    def inverted(self):
        """Gets the inverted of this PolicyCondition.  # noqa: E501

        This field is deprecated. Whether to invert the condition (ie the not operator). If the condition is `a == b` inverting the condition results in `not (a == b)`  # noqa: E501

        :return: The inverted of this PolicyCondition.  # noqa: E501
        :rtype: bool
        """
        return self._inverted

    @inverted.setter
    def inverted(self, inverted):
        """Sets the inverted of this PolicyCondition.

        This field is deprecated. Whether to invert the condition (ie the not operator). If the condition is `a == b` inverting the condition results in `not (a == b)`  # noqa: E501

        :param inverted: The inverted of this PolicyCondition.  # noqa: E501
        :type: bool
        """

        self._inverted = inverted

    @property
    def input_is_list(self):
        """Gets the input_is_list of this PolicyCondition.  # noqa: E501

        Whether the input to the condition is in a list. The semantics of the condition when this flag is set is to compare every item in the list to the `value` using the `operator`. The condition is satisfied if any item in the list evaluates to true   # noqa: E501

        :return: The input_is_list of this PolicyCondition.  # noqa: E501
        :rtype: bool
        """
        return self._input_is_list

    @input_is_list.setter
    def input_is_list(self, input_is_list):
        """Sets the input_is_list of this PolicyCondition.

        Whether the input to the condition is in a list. The semantics of the condition when this flag is set is to compare every item in the list to the `value` using the `operator`. The condition is satisfied if any item in the list evaluates to true   # noqa: E501

        :param input_is_list: The input_is_list of this PolicyCondition.  # noqa: E501
        :type: bool
        """

        self._input_is_list = input_is_list

    @property
    def value(self):
        """Gets the value of this PolicyCondition.  # noqa: E501

        A JSON string representing the value to compare against. The structure of the comparision and type of the value depends on the condition type. A comparision is done to determine the result of the condition (either `true` or `false`)  # noqa: E501

        :return: The value of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PolicyCondition.

        A JSON string representing the value to compare against. The structure of the comparision and type of the value depends on the condition type. A comparision is done to determine the result of the condition (either `true` or `false`)  # noqa: E501

        :param value: The value of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this PolicyCondition.  # noqa: E501

        The operator used to evaluate this condition. The operator field only applies when the condition type is type_object_attribute. The other types have implied operators.  # noqa: E501

        :return: The operator of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PolicyCondition.

        The operator used to evaluate this condition. The operator field only applies when the condition type is type_object_attribute. The other types have implied operators.  # noqa: E501

        :param operator: The operator of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["equals", "not_equals", "greater_than", "less_than", "in", "not_in"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    @property
    def field(self):
        """Gets the field of this PolicyCondition.  # noqa: E501

        The object path to a field to use as input to the policy condition. This field only applies when the condition type is type_object_attribute. The supported objects are currently `users`, and `clients`.   # noqa: E501

        :return: The field of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this PolicyCondition.

        The object path to a field to use as input to the policy condition. This field only applies when the condition type is type_object_attribute. The supported objects are currently `users`, and `clients`.   # noqa: E501

        :param field: The field of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                field is not None and len(field) > 511):
            raise ValueError("Invalid value for `field`, length must be less than or equal to `511`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                field is not None and not re.search(r'^([^\.]+\.?)*[^\.]+$', field)):  # noqa: E501
            raise ValueError(r"Invalid value for `field`, must be a follow pattern or equal to `/^([^\.]+\.?)*[^\.]+$/`")  # noqa: E501

        self._field = field

    @property
    def created(self):
        """Gets the created of this PolicyCondition.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this PolicyCondition.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this PolicyCondition.

        Creation time  # noqa: E501

        :param created: The created of this PolicyCondition.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this PolicyCondition.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this PolicyCondition.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this PolicyCondition.

        Update time  # noqa: E501

        :param updated: The updated of this PolicyCondition.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyCondition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicyCondition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UserApplicationAccessInfoStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'org_id': 'str',
        'org_name': 'str',
        'parent_org_id': 'str',
        'parent_org_name': 'str',
        'application_name': 'str',
        'application_url': 'str',
        'application_description': 'str',
        'application_category': 'str',
        'icon_url': 'str',
        'access_level': 'str',
        'application_default_role_name': 'str',
        'application_default_role_id': 'str',
        'roles': 'list[str]'
    }

    attribute_map = {
        'user_id': 'user_id',
        'org_id': 'org_id',
        'org_name': 'org_name',
        'parent_org_id': 'parent_org_id',
        'parent_org_name': 'parent_org_name',
        'application_name': 'application_name',
        'application_url': 'application_url',
        'application_description': 'application_description',
        'application_category': 'application_category',
        'icon_url': 'icon_url',
        'access_level': 'access_level',
        'application_default_role_name': 'application_default_role_name',
        'application_default_role_id': 'application_default_role_id',
        'roles': 'roles'
    }

    def __init__(self, user_id=None, org_id=None, org_name=None, parent_org_id=None, parent_org_name=None, application_name=None, application_url=None, application_description=None, application_category=None, icon_url='https://storage.googleapis.com/agilicus/logo.svg', access_level=None, application_default_role_name=None, application_default_role_id=None, roles=None, local_vars_configuration=None):  # noqa: E501
        """UserApplicationAccessInfoStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._org_id = None
        self._org_name = None
        self._parent_org_id = None
        self._parent_org_name = None
        self._application_name = None
        self._application_url = None
        self._application_description = None
        self._application_category = None
        self._icon_url = None
        self._access_level = None
        self._application_default_role_name = None
        self._application_default_role_id = None
        self._roles = None
        self.discriminator = None

        self.user_id = user_id
        self.org_id = org_id
        self.org_name = org_name
        if parent_org_id is not None:
            self.parent_org_id = parent_org_id
        if parent_org_name is not None:
            self.parent_org_name = parent_org_name
        self.application_name = application_name
        self.application_url = application_url
        if application_description is not None:
            self.application_description = application_description
        if application_category is not None:
            self.application_category = application_category
        if icon_url is not None:
            self.icon_url = icon_url
        self.access_level = access_level
        self.application_default_role_name = application_default_role_name
        self.application_default_role_id = application_default_role_id
        if roles is not None:
            self.roles = roles

    @property
    def user_id(self):
        """Gets the user_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id of the User to which this record applies.   # noqa: E501

        :return: The user_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserApplicationAccessInfoStatus.

        The unique id of the User to which this record applies.   # noqa: E501

        :param user_id: The user_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) > 40):
            raise ValueError("Invalid value for `user_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) < 1):
            raise ValueError("Invalid value for `user_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._user_id = user_id

    @property
    def org_id(self):
        """Gets the org_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id of the Organisation to which this record applies.   # noqa: E501

        :return: The org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this UserApplicationAccessInfoStatus.

        The unique id of the Organisation to which this record applies.   # noqa: E501

        :param org_id: The org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) < 1):
            raise ValueError("Invalid value for `org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._org_id = org_id

    @property
    def org_name(self):
        """Gets the org_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of Organisation to which this record applies.   # noqa: E501

        :return: The org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this UserApplicationAccessInfoStatus.

        The name of Organisation to which this record applies.   # noqa: E501

        :param org_name: The org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_name is None:  # noqa: E501
            raise ValueError("Invalid value for `org_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_name is not None and len(org_name) > 100):
            raise ValueError("Invalid value for `org_name`, length must be less than or equal to `100`")  # noqa: E501

        self._org_name = org_name

    @property
    def parent_org_id(self):
        """Gets the parent_org_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :return: The parent_org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._parent_org_id

    @parent_org_id.setter
    def parent_org_id(self, parent_org_id):
        """Sets the parent_org_id of this UserApplicationAccessInfoStatus.

        The unique id of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :param parent_org_id: The parent_org_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                parent_org_id is not None and len(parent_org_id) > 40):
            raise ValueError("Invalid value for `parent_org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                parent_org_id is not None and len(parent_org_id) < 1):
            raise ValueError("Invalid value for `parent_org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._parent_org_id = parent_org_id

    @property
    def parent_org_name(self):
        """Gets the parent_org_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :return: The parent_org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._parent_org_name

    @parent_org_name.setter
    def parent_org_name(self, parent_org_name):
        """Sets the parent_org_name of this UserApplicationAccessInfoStatus.

        The name of the parent of the Organisation to which this record applies. Omitted if the Organisation has no parent.   # noqa: E501

        :param parent_org_name: The parent_org_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                parent_org_name is not None and len(parent_org_name) > 100):
            raise ValueError("Invalid value for `parent_org_name`, length must be less than or equal to `100`")  # noqa: E501

        self._parent_org_name = parent_org_name

    @property
    def application_name(self):
        """Gets the application_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of the application.   # noqa: E501

        :return: The application_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """Sets the application_name of this UserApplicationAccessInfoStatus.

        The name of the application.   # noqa: E501

        :param application_name: The application_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and application_name is None:  # noqa: E501
            raise ValueError("Invalid value for `application_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_name is not None and len(application_name) > 128):
            raise ValueError("Invalid value for `application_name`, length must be less than or equal to `128`")  # noqa: E501

        self._application_name = application_name

    @property
    def application_url(self):
        """Gets the application_url of this UserApplicationAccessInfoStatus.  # noqa: E501

        The url of the application   # noqa: E501

        :return: The application_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_url

    @application_url.setter
    def application_url(self, application_url):
        """Sets the application_url of this UserApplicationAccessInfoStatus.

        The url of the application   # noqa: E501

        :param application_url: The application_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and application_url is None:  # noqa: E501
            raise ValueError("Invalid value for `application_url`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_url is not None and len(application_url) > 1024):
            raise ValueError("Invalid value for `application_url`, length must be less than or equal to `1024`")  # noqa: E501

        self._application_url = application_url

    @property
    def application_description(self):
        """Gets the application_description of this UserApplicationAccessInfoStatus.  # noqa: E501

        The description of the application   # noqa: E501

        :return: The application_description of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_description

    @application_description.setter
    def application_description(self, application_description):
        """Sets the application_description of this UserApplicationAccessInfoStatus.

        The description of the application   # noqa: E501

        :param application_description: The application_description of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """

        self._application_description = application_description

    @property
    def application_category(self):
        """Gets the application_category of this UserApplicationAccessInfoStatus.  # noqa: E501

        A category used to group similar applications together   # noqa: E501

        :return: The application_category of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_category

    @application_category.setter
    def application_category(self, application_category):
        """Sets the application_category of this UserApplicationAccessInfoStatus.

        A category used to group similar applications together   # noqa: E501

        :param application_category: The application_category of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                application_category is not None and len(application_category) > 100):
            raise ValueError("Invalid value for `application_category`, length must be less than or equal to `100`")  # noqa: E501

        self._application_category = application_category

    @property
    def icon_url(self):
        """Gets the icon_url of this UserApplicationAccessInfoStatus.  # noqa: E501

        A url pointing to an icon representing this application.   # noqa: E501

        :return: The icon_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this UserApplicationAccessInfoStatus.

        A url pointing to an icon representing this application.   # noqa: E501

        :param icon_url: The icon_url of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                icon_url is not None and len(icon_url) > 100):
            raise ValueError("Invalid value for `icon_url`, length must be less than or equal to `100`")  # noqa: E501

        self._icon_url = icon_url

    @property
    def access_level(self):
        """Gets the access_level of this UserApplicationAccessInfoStatus.  # noqa: E501

        Whether the user has access, has requested access, etc. The possible values have the following meanings:   - requested: the user has requested access to this instance.   - granted: the user has access to this instance.   - none: the user has no relation to this application.   # noqa: E501

        :return: The access_level of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this UserApplicationAccessInfoStatus.

        Whether the user has access, has requested access, etc. The possible values have the following meanings:   - requested: the user has requested access to this instance.   - granted: the user has access to this instance.   - none: the user has no relation to this application.   # noqa: E501

        :param access_level: The access_level of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and access_level is None:  # noqa: E501
            raise ValueError("Invalid value for `access_level`, must not be `None`")  # noqa: E501
        allowed_values = ["requested", "granted", "none"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and access_level not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(access_level, allowed_values)
            )

        self._access_level = access_level

    @property
    def application_default_role_name(self):
        """Gets the application_default_role_name of this UserApplicationAccessInfoStatus.  # noqa: E501

        The name of the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :return: The application_default_role_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_default_role_name

    @application_default_role_name.setter
    def application_default_role_name(self, application_default_role_name):
        """Sets the application_default_role_name of this UserApplicationAccessInfoStatus.

        The name of the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :param application_default_role_name: The application_default_role_name of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_name is not None and len(application_default_role_name) > 100):
            raise ValueError("Invalid value for `application_default_role_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_name is not None and len(application_default_role_name) < 1):
            raise ValueError("Invalid value for `application_default_role_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._application_default_role_name = application_default_role_name

    @property
    def application_default_role_id(self):
        """Gets the application_default_role_id of this UserApplicationAccessInfoStatus.  # noqa: E501

        The unique id the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :return: The application_default_role_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: str
        """
        return self._application_default_role_id

    @application_default_role_id.setter
    def application_default_role_id(self, application_default_role_id):
        """Sets the application_default_role_id of this UserApplicationAccessInfoStatus.

        The unique id the default role of the application. This will be granted to users by default when their access request has been approved.   # noqa: E501

        :param application_default_role_id: The application_default_role_id of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_id is not None and len(application_default_role_id) > 40):
            raise ValueError("Invalid value for `application_default_role_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_default_role_id is not None and len(application_default_role_id) < 1):
            raise ValueError("Invalid value for `application_default_role_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._application_default_role_id = application_default_role_id

    @property
    def roles(self):
        """Gets the roles of this UserApplicationAccessInfoStatus.  # noqa: E501

        The list of roles held by the user for the given application  # noqa: E501

        :return: The roles of this UserApplicationAccessInfoStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this UserApplicationAccessInfoStatus.

        The list of roles held by the user for the given application  # noqa: E501

        :param roles: The roles of this UserApplicationAccessInfoStatus.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserApplicationAccessInfoStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserApplicationAccessInfoStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorShareStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'exposed_shares_count': 'int',
        'server_running': 'bool',
        'server_start_time': 'datetime',
        'server_stop_time': 'datetime',
        'server_start_count': 'int',
        'server_stop_count': 'int',
        'per_share_info': 'list[AgentConnectorPerShareStats]'
    }

    attribute_map = {
        'exposed_shares_count': 'exposed_shares_count',
        'server_running': 'server_running',
        'server_start_time': 'server_start_time',
        'server_stop_time': 'server_stop_time',
        'server_start_count': 'server_start_count',
        'server_stop_count': 'server_stop_count',
        'per_share_info': 'per_share_info'
    }

    def __init__(self, exposed_shares_count=None, server_running=None, server_start_time=None, server_stop_time=None, server_start_count=None, server_stop_count=None, per_share_info=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorShareStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._exposed_shares_count = None
        self._server_running = None
        self._server_start_time = None
        self._server_stop_time = None
        self._server_start_count = None
        self._server_stop_count = None
        self._per_share_info = None
        self.discriminator = None

        self.exposed_shares_count = exposed_shares_count
        self.server_running = server_running
        if server_start_time is not None:
            self.server_start_time = server_start_time
        if server_stop_time is not None:
            self.server_stop_time = server_stop_time
        self.server_start_count = server_start_count
        self.server_stop_count = server_stop_count
        self.per_share_info = per_share_info

    @property
    def exposed_shares_count(self):
        """Gets the exposed_shares_count of this AgentConnectorShareStats.  # noqa: E501

        The total number of shares currently exposed.  # noqa: E501

        :return: The exposed_shares_count of this AgentConnectorShareStats.  # noqa: E501
        :rtype: int
        """
        return self._exposed_shares_count

    @exposed_shares_count.setter
    def exposed_shares_count(self, exposed_shares_count):
        """Sets the exposed_shares_count of this AgentConnectorShareStats.

        The total number of shares currently exposed.  # noqa: E501

        :param exposed_shares_count: The exposed_shares_count of this AgentConnectorShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and exposed_shares_count is None:  # noqa: E501
            raise ValueError("Invalid value for `exposed_shares_count`, must not be `None`")  # noqa: E501

        self._exposed_shares_count = exposed_shares_count

    @property
    def server_running(self):
        """Gets the server_running of this AgentConnectorShareStats.  # noqa: E501

        Whether the server exposing shares is running.  # noqa: E501

        :return: The server_running of this AgentConnectorShareStats.  # noqa: E501
        :rtype: bool
        """
        return self._server_running

    @server_running.setter
    def server_running(self, server_running):
        """Sets the server_running of this AgentConnectorShareStats.

        Whether the server exposing shares is running.  # noqa: E501

        :param server_running: The server_running of this AgentConnectorShareStats.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and server_running is None:  # noqa: E501
            raise ValueError("Invalid value for `server_running`, must not be `None`")  # noqa: E501

        self._server_running = server_running

    @property
    def server_start_time(self):
        """Gets the server_start_time of this AgentConnectorShareStats.  # noqa: E501

        When the server was started. If the server has never started, this value will be ommitted.   # noqa: E501

        :return: The server_start_time of this AgentConnectorShareStats.  # noqa: E501
        :rtype: datetime
        """
        return self._server_start_time

    @server_start_time.setter
    def server_start_time(self, server_start_time):
        """Sets the server_start_time of this AgentConnectorShareStats.

        When the server was started. If the server has never started, this value will be ommitted.   # noqa: E501

        :param server_start_time: The server_start_time of this AgentConnectorShareStats.  # noqa: E501
        :type: datetime
        """

        self._server_start_time = server_start_time

    @property
    def server_stop_time(self):
        """Gets the server_stop_time of this AgentConnectorShareStats.  # noqa: E501

        When the server was stopped. If the server has never stopped, this value will be ommitted.   # noqa: E501

        :return: The server_stop_time of this AgentConnectorShareStats.  # noqa: E501
        :rtype: datetime
        """
        return self._server_stop_time

    @server_stop_time.setter
    def server_stop_time(self, server_stop_time):
        """Sets the server_stop_time of this AgentConnectorShareStats.

        When the server was stopped. If the server has never stopped, this value will be ommitted.   # noqa: E501

        :param server_stop_time: The server_stop_time of this AgentConnectorShareStats.  # noqa: E501
        :type: datetime
        """

        self._server_stop_time = server_stop_time

    @property
    def server_start_count(self):
        """Gets the server_start_count of this AgentConnectorShareStats.  # noqa: E501

        The total number of times the share server has started  # noqa: E501

        :return: The server_start_count of this AgentConnectorShareStats.  # noqa: E501
        :rtype: int
        """
        return self._server_start_count

    @server_start_count.setter
    def server_start_count(self, server_start_count):
        """Sets the server_start_count of this AgentConnectorShareStats.

        The total number of times the share server has started  # noqa: E501

        :param server_start_count: The server_start_count of this AgentConnectorShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and server_start_count is None:  # noqa: E501
            raise ValueError("Invalid value for `server_start_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                server_start_count is not None and server_start_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `server_start_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._server_start_count = server_start_count

    @property
    def server_stop_count(self):
        """Gets the server_stop_count of this AgentConnectorShareStats.  # noqa: E501

        The total number of times the share server has stopped  # noqa: E501

        :return: The server_stop_count of this AgentConnectorShareStats.  # noqa: E501
        :rtype: int
        """
        return self._server_stop_count

    @server_stop_count.setter
    def server_stop_count(self, server_stop_count):
        """Sets the server_stop_count of this AgentConnectorShareStats.

        The total number of times the share server has stopped  # noqa: E501

        :param server_stop_count: The server_stop_count of this AgentConnectorShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and server_stop_count is None:  # noqa: E501
            raise ValueError("Invalid value for `server_stop_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                server_stop_count is not None and server_stop_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `server_stop_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._server_stop_count = server_stop_count

    @property
    def per_share_info(self):
        """Gets the per_share_info of this AgentConnectorShareStats.  # noqa: E501

        Information collected from the shares. Each share currently exposed will have a single record in this list. Shares which were once exposed, but no longer are, do not have records. If a share is later exposed, its statistics will be reset.   # noqa: E501

        :return: The per_share_info of this AgentConnectorShareStats.  # noqa: E501
        :rtype: list[AgentConnectorPerShareStats]
        """
        return self._per_share_info

    @per_share_info.setter
    def per_share_info(self, per_share_info):
        """Sets the per_share_info of this AgentConnectorShareStats.

        Information collected from the shares. Each share currently exposed will have a single record in this list. Shares which were once exposed, but no longer are, do not have records. If a share is later exposed, its statistics will be reset.   # noqa: E501

        :param per_share_info: The per_share_info of this AgentConnectorShareStats.  # noqa: E501
        :type: list[AgentConnectorPerShareStats]
        """
        if self.local_vars_configuration.client_side_validation and per_share_info is None:  # noqa: E501
            raise ValueError("Invalid value for `per_share_info`, must not be `None`")  # noqa: E501

        self._per_share_info = per_share_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorShareStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorShareStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class PolicySpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'issuer_id': 'str',
        'org_id': 'str',
        'supported_mfa_methods': 'list[str]',
        'default_action': 'str',
        'rules': 'list[PolicyRule]',
        'policy_groups': 'list[PolicyGroup]',
        'source': 'str'
    }

    attribute_map = {
        'name': 'name',
        'issuer_id': 'issuer_id',
        'org_id': 'org_id',
        'supported_mfa_methods': 'supported_mfa_methods',
        'default_action': 'default_action',
        'rules': 'rules',
        'policy_groups': 'policy_groups',
        'source': 'source'
    }

    def __init__(self, name=None, issuer_id=None, org_id=None, supported_mfa_methods=None, default_action=None, rules=None, policy_groups=None, source=None, local_vars_configuration=None):  # noqa: E501
        """PolicySpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._issuer_id = None
        self._org_id = None
        self._supported_mfa_methods = None
        self._default_action = None
        self._rules = None
        self._policy_groups = None
        self._source = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.issuer_id = issuer_id
        if org_id is not None:
            self.org_id = org_id
        self.supported_mfa_methods = supported_mfa_methods
        self.default_action = default_action
        if rules is not None:
            self.rules = rules
        if policy_groups is not None:
            self.policy_groups = policy_groups
        if source is not None:
            self.source = source

    @property
    def name(self):
        """Gets the name of this PolicySpec.  # noqa: E501

        The name of the policy so that it can be identifiable when applied to organizations or clients  # noqa: E501

        :return: The name of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PolicySpec.

        The name of the policy so that it can be identifiable when applied to organizations or clients  # noqa: E501

        :param name: The name of this PolicySpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def issuer_id(self):
        """Gets the issuer_id of this PolicySpec.  # noqa: E501

        The issuer that this policy applies to  # noqa: E501

        :return: The issuer_id of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._issuer_id

    @issuer_id.setter
    def issuer_id(self, issuer_id):
        """Sets the issuer_id of this PolicySpec.

        The issuer that this policy applies to  # noqa: E501

        :param issuer_id: The issuer_id of this PolicySpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                issuer_id is not None and len(issuer_id) > 40):
            raise ValueError("Invalid value for `issuer_id`, length must be less than or equal to `40`")  # noqa: E501

        self._issuer_id = issuer_id

    @property
    def org_id(self):
        """Gets the org_id of this PolicySpec.  # noqa: E501

        The org id corresponding to the issuer whose policy you are updating  # noqa: E501

        :return: The org_id of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this PolicySpec.

        The org id corresponding to the issuer whose policy you are updating  # noqa: E501

        :param org_id: The org_id of this PolicySpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def supported_mfa_methods(self):
        """Gets the supported_mfa_methods of this PolicySpec.  # noqa: E501

        A list of supported MFA methods. An empty list implies that no MFA methods are acceptable  # noqa: E501

        :return: The supported_mfa_methods of this PolicySpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_mfa_methods

    @supported_mfa_methods.setter
    def supported_mfa_methods(self, supported_mfa_methods):
        """Sets the supported_mfa_methods of this PolicySpec.

        A list of supported MFA methods. An empty list implies that no MFA methods are acceptable  # noqa: E501

        :param supported_mfa_methods: The supported_mfa_methods of this PolicySpec.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and supported_mfa_methods is None:  # noqa: E501
            raise ValueError("Invalid value for `supported_mfa_methods`, must not be `None`")  # noqa: E501

        self._supported_mfa_methods = supported_mfa_methods

    @property
    def default_action(self):
        """Gets the default_action of this PolicySpec.  # noqa: E501

        The action to take if none of the conditions evaluate to true. Actions are case sensitive.  # noqa: E501

        :return: The default_action of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._default_action

    @default_action.setter
    def default_action(self, default_action):
        """Sets the default_action of this PolicySpec.

        The action to take if none of the conditions evaluate to true. Actions are case sensitive.  # noqa: E501

        :param default_action: The default_action of this PolicySpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and default_action is None:  # noqa: E501
            raise ValueError("Invalid value for `default_action`, must not be `None`")  # noqa: E501
        allowed_values = ["do_mfa", "dont_mfa", "deny_login", "allow_login", "authenticate"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and default_action not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `default_action` ({0}), must be one of {1}"  # noqa: E501
                .format(default_action, allowed_values)
            )

        self._default_action = default_action

    @property
    def rules(self):
        """Gets the rules of this PolicySpec.  # noqa: E501

        The list of rules defining the policy. A rule consists of conditions, actions, and a priority  # noqa: E501

        :return: The rules of this PolicySpec.  # noqa: E501
        :rtype: list[PolicyRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this PolicySpec.

        The list of rules defining the policy. A rule consists of conditions, actions, and a priority  # noqa: E501

        :param rules: The rules of this PolicySpec.  # noqa: E501
        :type: list[PolicyRule]
        """

        self._rules = rules

    @property
    def policy_groups(self):
        """Gets the policy_groups of this PolicySpec.  # noqa: E501

        A list of policy groups ordered by priority. The first item in the list represents the group with the highest priority. A policy group consists of a list of rules. All rules in a group of higher priority will have higher precedence than any rule in a group of lower priority.   # noqa: E501

        :return: The policy_groups of this PolicySpec.  # noqa: E501
        :rtype: list[PolicyGroup]
        """
        return self._policy_groups

    @policy_groups.setter
    def policy_groups(self, policy_groups):
        """Sets the policy_groups of this PolicySpec.

        A list of policy groups ordered by priority. The first item in the list represents the group with the highest priority. A policy group consists of a list of rules. All rules in a group of higher priority will have higher precedence than any rule in a group of lower priority.   # noqa: E501

        :param policy_groups: The policy_groups of this PolicySpec.  # noqa: E501
        :type: list[PolicyGroup]
        """

        self._policy_groups = policy_groups

    @property
    def source(self):
        """Gets the source of this PolicySpec.  # noqa: E501

        An identifier for the policy this policy was based on.  # noqa: E501

        :return: The source of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this PolicySpec.

        An identifier for the policy this policy was based on.  # noqa: E501

        :param source: The source of this PolicySpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                source is not None and len(source) > 100):
            raise ValueError("Invalid value for `source`, length must be less than or equal to `100`")  # noqa: E501

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicySpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicySpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class RuleQueryParameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'exact_match': 'str'
    }

    attribute_map = {
        'name': 'name',
        'exact_match': 'exact_match'
    }

    def __init__(self, name=None, exact_match=None, local_vars_configuration=None):  # noqa: E501
        """RuleQueryParameter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._exact_match = None
        self.discriminator = None

        self.name = name
        if exact_match is not None:
            self.exact_match = exact_match

    @property
    def name(self):
        """Gets the name of this RuleQueryParameter.  # noqa: E501

        The name of the query parameter.  # noqa: E501

        :return: The name of this RuleQueryParameter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RuleQueryParameter.

        The name of the query parameter.  # noqa: E501

        :param name: The name of this RuleQueryParameter.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def exact_match(self):
        """Gets the exact_match of this RuleQueryParameter.  # noqa: E501

        The given query parameter must exist and equal this. Can be templatized with jinja2 using the definitions collection.   # noqa: E501

        :return: The exact_match of this RuleQueryParameter.  # noqa: E501
        :rtype: str
        """
        return self._exact_match

    @exact_match.setter
    def exact_match(self, exact_match):
        """Sets the exact_match of this RuleQueryParameter.

        The given query parameter must exist and equal this. Can be templatized with jinja2 using the definitions collection.   # noqa: E501

        :param exact_match: The exact_match of this RuleQueryParameter.  # noqa: E501
        :type: str
        """

        self._exact_match = exact_match

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleQueryParameter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RuleQueryParameter):
            return True

        return self.to_dict() != other.to_dict()
